@@ -1,16 +1,36 @@
 # Copyright 2021 VMware, Inc.
 # SPDX-License-Identifier: Apache-2.0
 import logging
+from contextlib import contextmanager
 from typing import Optional
 
-from sqllineage.core.models import Table
-from sqllineage.runner import LineageRunner
 from vdk.api.lineage.sql.data import LineageData
 from vdk.api.lineage.sql.data import LineageTable
 
 log = logging.getLogger(__name__)
 
 
+@contextmanager
+def no_op_dict_config():
+    """
+    Hacky workaround to import sqllineage as it is overriding logging configuration in sqllineage.__init__
+    It's likely because LineageRunner is considered private so we are a bit abusing the tool here.
+    """
+    import logging.config
+
+    cached_dict_config = logging.config.dictConfig
+    logging.config.dictConfig = lambda x: None
+    try:
+        yield
+    finally:
+        logging.config.dictConfig = cached_dict_config
+
+
+with no_op_dict_config():
+    from sqllineage.core.models import Table
+    from sqllineage.runner import LineageRunner
+
+
 def get_table_lineage_from_query(
     query: str, schema: Optional[str], catalog: Optional[str]
 ) -> LineageData:
@@ -22,6 +42,7 @@ def get_table_lineage_from_query(
     :param catalog: The catalog which is queried
     :return: A tuple with (table_from, table_to) if it is a RENAME TABLE query, None otherwise.
     """
+
     runner = LineageRunner(query)
 
     if len(runner.statements_parsed) == 0:
@@ -60,15 +81,19 @@ def get_table_lineage_from_query(
     )
 
 
-def _lineage_table_from_name(table: Table, schema: str, catalog: str) -> LineageTable:
+def _lineage_table_from_name(
+    table: Table, default_schema: str, default_catalog: str
+) -> LineageTable:
+    from sqllineage.core.models import Table
+
     tokens = []
     if table.schema:
         tokens = table.schema.raw_name.split(".")
 
     if len(tokens) == 0:
-        return LineageTable(catalog, schema, table.raw_name)
+        return LineageTable(default_catalog, default_schema, table.raw_name)
     elif len(tokens) == 1:
-        return LineageTable(catalog, tokens[0], table.raw_name)
+        return LineageTable(default_catalog, tokens[0], table.raw_name)
     elif len(tokens) == 2:
         return LineageTable(tokens[0], tokens[1], table.raw_name)
     else:
